@@ -1,13 +1,13 @@
 from datetime import date
 import json
 import pandas
-from quick_resto_objects.quick_resto_object import QuickRestoObject
+from quick_resto_API.quick_resto_objects.quick_resto_object import QuickRestoObject, QuickRestoObjectEncoder
 
-from quick_resto_api import QuickRestoApi
-from quick_resto_objects.modules.crm.account_type import AccountType
-from quick_resto_objects.modules.crm.account_balance import AccountBalance
-from quick_resto_objects.modules.crm.customer import CrmCustomer
-from quick_resto_objects.modules.crm.customer_token import CustomerToken
+from quick_resto_API.quick_resto_api import QuickRestoApi
+from quick_resto_API.quick_resto_objects.modules.crm.account_type import AccountType
+from quick_resto_API.quick_resto_objects.modules.crm.account_balance import AccountBalance
+from quick_resto_API.quick_resto_objects.modules.crm.customer import CrmCustomer
+from quick_resto_API.quick_resto_objects.modules.crm.customer_token import CustomerToken
 
 class QuickRestoInterface:
     @property
@@ -113,33 +113,39 @@ class QuickRestoInterface:
         file = file_name + ".csv"
 
         if isinstance(json_data, QuickRestoObject):
-            pandas.DataFrame(json.loads(json.dumps(self._get_not_nested_json(json_data.get_json_object())))).to_csv(file)
+            pandas.DataFrame(json.loads(json.dumps(self._get_not_nested_json(json_data.get_json_object()), cls=QuickRestoObjectEncoder, indent=4, ensure_ascii=False))).to_csv(file)
 
         if isinstance(json_data, list):
             list_of_json_objects = list()
 
             for item in json_data:
                 if isinstance(item, QuickRestoObject):
-                    list_of_json_objects.append(self._get_not_nested_json(item.get_json_object()))
+                    json_item = {}
+                    self._get_not_nested_json(item.get_json_object(), json_item)
 
-            pandas.DataFrame(json.loads(json.dumps(list_of_json_objects))).to_csv(file)
+                    list_of_json_objects.append(json_item)
+
+            pandas.DataFrame(json.loads(json.dumps(list_of_json_objects, cls=QuickRestoObjectEncoder, indent=4, ensure_ascii=False))).to_csv(file)
 
     def convert_to_csv(self, json_data:list|QuickRestoObject) -> str:
         if isinstance(json_data, QuickRestoObject):
-            return pandas.DataFrame(json.loads(json.dumps(self._get_not_nested_json(json_data.get_json_object())))).to_csv()
+            return pandas.DataFrame(json.loads(json.dumps(self._get_not_nested_json(json_data.get_json_object()), cls=QuickRestoObjectEncoder, indent=4, ensure_ascii=False))).to_csv()
 
         if isinstance(json_data, list):
             list_of_json_objects = list()
 
             for item in json_data:
                 if isinstance(item, QuickRestoObject):
-                    list_of_json_objects.append(self._get_not_nested_json(item.get_json_object()))
+                    json_item = {}
+                    self._get_not_nested_json(item.get_json_object(), json_item)
 
-            return pandas.DataFrame(json.loads(json.dumps(list_of_json_objects))).to_csv()
+                    list_of_json_objects.append(json_item)
+
+            return pandas.DataFrame(json.loads(json.dumps(list_of_json_objects), cls=QuickRestoObjectEncoder, indent=4, ensure_ascii=False)).to_csv()
 
         return ""
 
-    def _get_not_nested_json(self, json:dict, result_json:dict = dict(), nested_names:list = list()) -> dict:
+    def _get_not_nested_json(self, json:dict, result_json:dict, nested_names:list = list()):
         for i in json.keys():
             if isinstance(json[i], dict):
                 nested_names.append(i + "__")
@@ -149,5 +155,3 @@ class QuickRestoInterface:
                 nested_names.pop()
             else:
                 result_json["".join(nested_names) + i] =  json[i]
-
-        return result_json
