@@ -1,6 +1,6 @@
-from quick_resto_objects.modules.crm.account_type import AccountType
-from quick_resto_objects.modules.crm.account_balance import AccountBalance
-from quick_resto_objects.quick_resto_object import QuickRestoObject
+from quick_resto_API.quick_resto_objects.modules.crm.account_type import AccountType
+from quick_resto_API.quick_resto_objects.modules.crm.account_balance import AccountBalance
+from quick_resto_API.quick_resto_objects.quick_resto_object import QuickRestoObject
 
 
 class CustomerAccount(QuickRestoObject):
