@@ -1,5 +1,5 @@
-from quick_resto_objects.modules.warehouse.employee import Employee
-from quick_resto_objects.quick_resto_object import QuickRestoObject
+from quick_resto_API.quick_resto_objects.modules.warehouse.employee import Employee
+from quick_resto_API.quick_resto_objects.quick_resto_object import QuickRestoObject
 
 
 class Store(QuickRestoObject):
